==> tyrus-monitoring-jmx-1.8.3-sources.jar: org/glassfish/tyrus/ext/monitoring/jmx/EndpointMXBeanImpl.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2014 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.tyrus.ext.monitoring.jmx;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

/**
 * @author Petr Janouch (petr.janouch at oracle.com)
 */
class EndpointMXBeanImpl extends BaseMXBeanImpl implements EndpointMXBean, Serializable {

    private static final long serialVersionUID = 1362028955470529660L;
    
    private final String endpointPath;
    private final String endpointClassName;
    private final Callable<Integer> openSessionsCount;
    private final Callable<Integer> maxOpenSessionsCount;
    private final Map<String, SessionMXBean> sessionMXBeans = new ConcurrentHashMap<String, SessionMXBean>();

    public EndpointMXBeanImpl(MessageStatisticsSource sentMessageStatistics, MessageStatisticsSource receivedMessageStatistics, String endpointPath, String endpointClassName, Callable<Integer> openSessionsCount, Callable<Integer> maxOpenSessionsCount, Callable<List<ErrorCount>> errorCounts, MessageStatisticsMXBean textMessageStatisticsMXBean, MessageStatisticsMXBean binaryMessageStatisticsMXBean, MessageStatisticsMXBean controlMessageStatisticsMXBean) {
        super(sentMessageStatistics, receivedMessageStatistics, errorCounts, textMessageStatisticsMXBean, binaryMessageStatisticsMXBean, controlMessageStatisticsMXBean);
        this.endpointPath = endpointPath;
        this.endpointClassName = endpointClassName;
        this.openSessionsCount = openSessionsCount;
        this.maxOpenSessionsCount = maxOpenSessionsCount;
    }

    @Override
    public String getEndpointPath() {
        return endpointPath;
    }

    @Override
    public String getEndpointClassName() {
        return endpointClassName;
    }

    @Override
    public int getOpenSessionsCount() {
        return openSessionsCount.call();
    }

    @Override
    public int getMaximalOpenSessionsCount() {
        return maxOpenSessionsCount.call();
    }

    @Override
    public List<SessionMXBean> getSessionMXBeans() {
        return new ArrayList<SessionMXBean>(sessionMXBeans.values());
    }

    void putSessionMXBean(String sessionId, SessionMXBean sessionMXBean) {
        sessionMXBeans.put(sessionId, sessionMXBean);
    }

    void removeSessionMXBean(String sessionId) {
        sessionMXBeans.remove(sessionId);
    }
}

==> tyrus-monitoring-jmx-1.14-sources.jar: org/glassfish/tyrus/ext/monitoring/jmx/EndpointMXBeanImpl.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2014-2016 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.tyrus.ext.monitoring.jmx;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

/**
 * @author Petr Janouch
 */
class EndpointMXBeanImpl extends BaseMXBeanImpl implements EndpointMXBean, Serializable {

    private static final long serialVersionUID = 1362028955470529660L;

    private final String endpointPath;
    private final String endpointClassName;
    private final Callable<Integer> openSessionsCount;
    private final Callable<Integer> maxOpenSessionsCount;
    private final Map<String, SessionMXBean> sessionMXBeans = new ConcurrentHashMap<String, SessionMXBean>();

    public EndpointMXBeanImpl(
            MessageStatisticsSource sentMessageStatistics, MessageStatisticsSource receivedMessageStatistics,
            String endpointPath, String endpointClassName, Callable<Integer> openSessionsCount,
            Callable<Integer> maxOpenSessionsCount, Callable<List<ErrorCount>> errorCounts,
            MessageStatisticsMXBean textMessageStatisticsMXBean, MessageStatisticsMXBean binaryMessageStatisticsMXBean,
            MessageStatisticsMXBean controlMessageStatisticsMXBean) {
        super(sentMessageStatistics, receivedMessageStatistics, errorCounts, textMessageStatisticsMXBean,
              binaryMessageStatisticsMXBean, controlMessageStatisticsMXBean);
        this.endpointPath = endpointPath;
        this.endpointClassName = endpointClassName;
        this.openSessionsCount = openSessionsCount;
        this.maxOpenSessionsCount = maxOpenSessionsCount;
    }

    @Override
    public String getEndpointPath() {
        return endpointPath;
    }

    @Override
    public String getEndpointClassName() {
        return endpointClassName;
    }

    @Override
    public int getOpenSessionsCount() {
        return openSessionsCount.call();
    }

    @Override
    public int getMaximalOpenSessionsCount() {
        return maxOpenSessionsCount.call();
    }

    @Override
    public List<SessionMXBean> getSessionMXBeans() {
        return new ArrayList<SessionMXBean>(sessionMXBeans.values());
    }

    void putSessionMXBean(String sessionId, SessionMXBean sessionMXBean) {
        sessionMXBeans.put(sessionId, sessionMXBean);
    }

    void removeSessionMXBean(String sessionId) {
        sessionMXBeans.remove(sessionId);
    }
}
